==> nextcloud-24.0.9.tgz: nextcloud/apps/serverinfo/l10n/pl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informacje o procesorze są niedostępne",
    "Load average: {cpu} (last minute)" : "Średnie obciążenie: {cpu} (ostatnia minuta)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Pamięć RAM: Całkowita: {memTotalBytes}/Bieżące użycie: {memUsageBytes}",
    "RAM info not available" : "Informacje o pamięci RAM są niedostępne",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Pamięć SWAP: Całkowita: {swapTotalBytes}/Bieżące użycie: {swapUsageBytes}",
    "SWAP info not available" : "Informacje o pamięci SWAP są niedostępne",
    "Users" : "Użytkownicy",
    "Groups" : "Grupy",
    "Links" : "Linki",
    "Emails" : "E-maile",
    "Federated sent" : "Wysłane do federacji",
    "Federated received" : "Otrzymane z federacji",
    "Talk conversations" : "Rozmowy Talk",
    "24 hours" : "24 godziny",
    "1 hour" : "1 godzina",
    "5 mins" : "5 minut",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Niewspierane!",
    "Press ⌘-C to copy." : "Aby skopiować wciśnij ⌘-C.",
    "Press Ctrl-C to copy." : "Aby skopiować wciśnij Ctrl+C.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Aplikacja monitorująca z przydatnymi informacjami o serwerze",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zapewnia przydatne informacje o serwerze, takie jak obciążenie procesora, użycie pamięci RAM, wykorzystanie dysku, liczba użytkowników itp.",
    "Operating System:" : "System operacyjny:",
    "CPU:" : "Procesor CPU:",
    "Unknown Processor" : "Procesor nieznany",
    "Memory:" : "Pamięć:",
    "Server time:" : "Czas serwera:",
    "Uptime:" : "Czas pracy:",
    "Temperature" : "Temperatura",
    "Load" : "Obciążenie",
    "Memory" : "Pamięć",
    "Disk" : "Dysk",
    "Mount:" : "Zamontowany:",
    "Filesystem:" : "System plików:",
    "Size:" : "Rozmiar:",
    "Available:" : "Dostępny:",
    "Used:" : "Używany:",
    "You will get a notification once one of your disks is nearly full." : "Otrzymasz powiadomienie, gdy jeden z dysków będzie prawie zapełniony.",
    "Files:" : "Pliki:",
    "Storages:" : "Magazyny:",
    "Free Space:" : "Wolne miejsce:",
    "Network" : "Sieć",
    "Hostname:" : "Nazwa hosta:",
    "DNS:" : "DNS:",
    "Gateway:" : "Brama:",
    "Status:" : "Status:",
    "Speed:" : "Prędkość:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktywni użytkownicy",
    "Total users:" : "Ilość użytkowników:",
    "Shares" : "Udostępnienia",
    "PHP" : "PHP",
    "Version:" : "Wersja:",
    "Memory limit:" : "Limit pamięci:",
    "Max execution time:" : "Maksymalny czas wykonania:",
    "Upload max size:" : "Limit wielkości przesyłanego pliku (upload_max_filesize):",
    "Extensions:" : "Rozszerzenia:",
    "Unable to list extensions" : "Nie można wyświetlić listy rozszerzeń",
    "Database" : "Baza danych",
    "Type:" : "Rodzaj:",
    "External monitoring tool" : "Zewnętrzne narzędzie monitorujące",
    "You can connect an external monitoring tool by using this end point:" : "Możesz podłączyć zewnętrzne narzędzie do monitorowania, używając tego punktu końcowego:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Dołączenie \"?format=json\" na końcu adresu URL daje wynik w formacie JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Aby użyć tokena dostępu, wygeneruj go, a następnie ustaw za pomocą następującego polecenia:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Następnie przekaż token z nagłówkiem \"NC-Token\" podczas odpytywania powyższego adresu URL.",
    "Operating System" : "System operacyjny",
    "CPU" : "Procesor CPU",
    "Server time" : "Serwer czasu",
    "Uptime" : "Czas pracy",
    "Mount" : "Zamontowany",
    "Filesystem" : "System plików",
    "Size" : "Rozmiar",
    "Available" : "Dostępny",
    "Used" : "Używany",
    "Files" : "Pliki",
    "Storages" : "Magazyny",
    "Free Space" : "Wolne miejsce",
    "Hostname" : "Nazwa hosta",
    "DNS" : "DNS",
    "Gateway" : "Brama",
    "Status" : "Status",
    "Speed" : "Prędkość",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Total users" : "Ilość użytkowników",
    "Version" : "Wersja",
    "Memory limit" : "Limit pamięci",
    "Max execution time" : "Maksymalny czas wykonania",
    "Upload max size" : "Limit wielkości przesyłanego pliku",
    "Type" : "Rodzaj",
    "You can connect an external monitoring tool by using this end point" : "Możesz podłączyć zewnętrzne narzędzie do monitorowania, używając tego punktu końcowego",
    "To use an access token, please generate one then set it using the following command" : "Aby użyć tokena dostępu, wygeneruj go, a następnie ustaw za pomocą następującego polecenia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/serverinfo/l10n/pl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informacje o procesorze są niedostępne",
    "Load average: {cpu} (last minute)" : "Średnie obciążenie: {cpu} (ostatnia minuta)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Pamięć RAM: Całkowita: {memTotalBytes}/Bieżące użycie: {memUsageBytes}",
    "RAM info not available" : "Informacje o pamięci RAM są niedostępne",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Pamięć SWAP: Całkowita: {swapTotalBytes}/Bieżące użycie: {swapUsageBytes}",
    "SWAP info not available" : "Informacje o pamięci SWAP są niedostępne",
    "Not supported!" : "Niewspierane!",
    "Press ⌘-C to copy." : "Aby skopiować wciśnij ⌘-C.",
    "Press Ctrl-C to copy." : "Aby skopiować wciśnij Ctrl+C.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Aplikacja monitorująca z przydatnymi informacjami o serwerze",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zapewnia przydatne informacje o serwerze, takie jak obciążenie procesora, użycie pamięci RAM, wykorzystanie dysku, liczba użytkowników itp.",
    "Operating System:" : "System operacyjny:",
    "CPU:" : "Procesor CPU:",
    "Unknown Processor" : "Procesor nieznany",
    "Memory:" : "Pamięć:",
    "Server time:" : "Czas serwera:",
    "Uptime:" : "Czas pracy:",
    "Temperature" : "Temperatura",
    "Load" : "Obciążenie",
    "Memory" : "Pamięć",
    "Disk" : "Dysk",
    "Mount:" : "Zamontowany:",
    "Filesystem:" : "System plików:",
    "Size:" : "Rozmiar:",
    "Available:" : "Dostępny:",
    "Used:" : "Używany:",
    "You will get a notification once one of your disks is nearly full." : "Otrzymasz powiadomienie, gdy jeden z dysków będzie prawie zapełniony.",
    "Files:" : "Pliki:",
    "Storages:" : "Magazyny:",
    "Free Space:" : "Wolne miejsce:",
    "Network" : "Sieć",
    "Hostname:" : "Nazwa hosta:",
    "DNS:" : "DNS:",
    "Gateway:" : "Brama:",
    "Status:" : "Status:",
    "Speed:" : "Prędkość:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktywni użytkownicy",
    "Total users:" : "Ilość użytkowników:",
    "24 hours:" : "24 godziny:",
    "1 hour:" : "1 godzina:",
    "5 mins:" : "5 minut:",
    "Shares" : "Udostępnienia",
    "Users:" : "Użytkownicy:",
    "Groups:" : "Grupy:",
    "Links:" : "Linki:",
    "Emails:" : "E-maile:",
    "Federated sent:" : "Wysłane do federacji:",
    "Federated received:" : "Otrzymane z federacji:",
    "Talk conversations:" : "Rozmowy Talk:",
    "PHP" : "PHP",
    "Version:" : "Wersja:",
    "Memory limit:" : "Limit pamięci:",
    "Max execution time:" : "Maksymalny czas wykonania:",
    "Upload max size:" : "Limit wielkości przesyłanego pliku (upload_max_filesize):",
    "Extensions:" : "Rozszerzenia:",
    "Unable to list extensions" : "Nie można wyświetlić listy rozszerzeń",
    "Database" : "Baza danych",
    "Type:" : "Rodzaj:",
    "External monitoring tool" : "Zewnętrzne narzędzie monitorujące",
    "You can connect an external monitoring tool by using this end point:" : "Możesz podłączyć zewnętrzne narzędzie do monitorowania, używając tego punktu końcowego:",
    "Copy" : "Kopiuj",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Dołączenie \"?format=json\" na końcu adresu URL daje wynik w formacie JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Aby użyć tokena dostępu, wygeneruj go, a następnie ustaw za pomocą następującego polecenia:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Następnie przekaż token z nagłówkiem \"NC-Token\" podczas odpytywania powyższego adresu URL.",
    "Users" : "Użytkownicy",
    "Groups" : "Grupy",
    "Links" : "Linki",
    "Emails" : "E-maile",
    "Federated sent" : "Wysłane do federacji",
    "Federated received" : "Otrzymane z federacji",
    "Talk conversations" : "Rozmowy Talk",
    "24 hours" : "24 godziny",
    "1 hour" : "1 godzina",
    "5 mins" : "5 minut",
    "Copied!" : "Skopiowano!",
    "Operating System" : "System operacyjny",
    "CPU" : "Procesor CPU",
    "Server time" : "Serwer czasu",
    "Uptime" : "Czas pracy",
    "Mount" : "Zamontowany",
    "Filesystem" : "System plików",
    "Size" : "Rozmiar",
    "Available" : "Dostępny",
    "Used" : "Używany",
    "Files" : "Pliki",
    "Storages" : "Magazyny",
    "Free Space" : "Wolne miejsce",
    "Hostname" : "Nazwa hosta",
    "DNS" : "DNS",
    "Gateway" : "Brama",
    "Status" : "Status",
    "Speed" : "Prędkość",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Total users" : "Ilość użytkowników",
    "Version" : "Wersja",
    "Memory limit" : "Limit pamięci",
    "Max execution time" : "Maksymalny czas wykonania",
    "Upload max size" : "Limit wielkości przesyłanego pliku",
    "Type" : "Rodzaj",
    "You can connect an external monitoring tool by using this end point" : "Możesz podłączyć zewnętrzne narzędzie do monitorowania, używając tego punktu końcowego",
    "To use an access token, please generate one then set it using the following command" : "Aby użyć tokena dostępu, wygeneruj go, a następnie ustaw za pomocą następującego polecenia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
